<?php
/**
 * Plugin Name: ExortPress Simple Photo Gallery
 * Plugin URI: http://exortpress.com
 * Description: This plugin displays a simple gallery of photos.
 * Version: 1.1.1
 * Author: Omar Tariq
 * Author URI: http://exortpress.com
 * License: GPL2
 */

/* plugin_dir_url() includes a trailing slash ("/"). */
define('EXORTPRESS_PLUGIN_URL_SIMPLE_PHOTO_GALLERY', plugin_dir_url( __FILE__ ));

defined('ABSPATH') or die("No script kiddies please!");

function exortpress_plugin_simple_photo_gallery_style() {
	wp_enqueue_script( 'exortpress_plugin_simple_photo_gallery_style', EXORTPRESS_PLUGIN_URL_SIMPLE_PHOTO_GALLERY . 'src/galleria/galleria-1.4.2.min.js', array('jquery') );
}

add_action( 'wp_enqueue_scripts', 'exortpress_plugin_simple_photo_gallery_style' );

function exortpress_plugin_simple_photo_gallery_style_in_footer() {
	?>
	<script>
		jQuery(document).ready(function($){

			if( jQuery('.exortpress-spg').length ) {
				Galleria.loadTheme( '<?php echo EXORTPRESS_PLUGIN_URL_SIMPLE_PHOTO_GALLERY ?>src/galleria/themes/classic/galleria.classic.min.js');
				Galleria.run('.exortpress-spg');
			}

		});/* jquery document ready */

	</script>
	<style>
	    .exortpress-spg{ width: 100%; height: 400px; background: #000 }
	</style>
	<?php
}

add_action('wp_head', 'exortpress_plugin_simple_photo_gallery_style_in_footer');

/**
 * Creates a shortcode for displaying gallery
 * @author Omar Tariq <otjutt@gmail.com>
 */
function callback_exortpress_simple_photo_gallery( $args ){
	/* Don't echo! Always return */

	if(!array_key_exists('id', $args)) {
		return '';
	}

	$return_result = '<div class="exortpress-spg">';
	$attachment_ids = explode(',', get_post_meta( $args['id'], 'attachment_ids', true ));
	foreach($attachment_ids as $id) {
		$return_result = $return_result . '<img src="' . wp_get_attachment_image_src($id, "full")[0] . '">';
	}

	$return_result = $return_result . '</div">';


	return $return_result;
}

add_shortcode( 'exortpress_simple_photo_gallery', 'callback_exortpress_simple_photo_gallery' );


function exortpress_register_post_type_simple_photo_gallery() {

	$labels = array(
		'name'               => _x( 'Photo Galleries', 'post type general name', 'your-plugin-textdomain' ),
		'singular_name'      => _x( 'Photo Gallery', 'post type singular name', 'your-plugin-textdomain' ),
		'menu_name'          => _x( 'ExortPress Simple Photo Gallery', 'admin menu', 'your-plugin-textdomain' ),
		'name_admin_bar'     => _x( 'ExortPress Simple Photo Gallery', 'add new on admin bar', 'your-plugin-textdomain' ),
		'add_new'            => _x( 'Add New Gallery', 'book', 'your-plugin-textdomain' ),
		'add_new_item'       => __( 'Add New Gallery', 'your-plugin-textdomain' ),
		'new_item'           => __( 'New Gallery', 'your-plugin-textdomain' ),
		'edit_item'          => __( 'Edit Gallery', 'your-plugin-textdomain' ),
		'view_item'          => __( 'View Gallery', 'your-plugin-textdomain' ),
		'all_items'          => __( 'All Galleries', 'your-plugin-textdomain' ),
		'search_items'       => __( 'Search Galleries', 'your-plugin-textdomain' ),
		'parent_item_colon'  => __( 'Parent Galleries:', 'your-plugin-textdomain' ),
		'not_found'          => __( 'No Galleries found.', 'your-plugin-textdomain' ),
		'not_found_in_trash' => __( 'No Galleries found in Trash.', 'your-plugin-textdomain' )

	);

	$args = array(
		'labels'             => $labels,
		'public'			 => true,
		'label'  			 => 'ExortPress Simple Photo Gallery',
		'supports'           => array( 'title'),
		'menu_icon' 		 => EXORTPRESS_PLUGIN_URL_SIMPLE_PHOTO_GALLERY . '/src/img/menu_icon.png'
    );
    register_post_type( 'exortpress-spg', $args );
}
add_action( 'init', 'exortpress_register_post_type_simple_photo_gallery' );

/**
 * Adds a box to the main column on the Post and Page edit screens.
 */
function exortpress_spg_meta_box_gallery_id() {

	add_meta_box(
		'exortpress_spg_section_gallery_id',
		__( 'Using This Gallery', 'exortpress' ),
		'exortpress_spg_meta_box_gallery_id_callback',
		'exortpress-spg',
		'side',
		'high'
	);

	remove_meta_box( 'slugdiv', 'exortpress-spg', 'normal' );

}
add_action( 'add_meta_boxes', 'exortpress_spg_meta_box_gallery_id' );

function exortpress_spg_meta_box_gallery_id_callback( $post ) {
	?>
	<script>
		jQuery(document).ready(function($){

			$(document).ready(function() {
			    $(".selectable-on-click:text").on('mouseup', function() { $(this).select(); });
			});

		});/* jquery document ready */
	</script>
	<?php
	global $post;
	$post_id = $post->ID;
	echo '<p>Copy the following shortcode, and paste it in posts or pages where you want to display the gallery.</p>';
	echo '<input class="selectable-on-click" type="text" value="[exortpress_simple_photo_gallery id=\'' . $post_id . '\']" style="width:100%;" readonly>';
	echo '<p>Copy the following php code, and paste it in your theme files where you want to display the gallery.</p>';
	echo '<input class="selectable-on-click" type="text" value="<?php echo do_shortcode(\'[exortpress_simple_photo_gallery id=&quot;' . $post_id . '&quot;]\'); ?>" style="width:100%;" readonly>';

}

/**
 * Adds a box to the main column on the Post and Page edit screens.
 */
function exortpress_spg_meta_box() {

	add_meta_box(
		'exortpress_spg_section_photos',
		__( 'Photos', 'exortpress' ),
		'exortpress_spg_meta_box_callback',
		'exortpress-spg',
		'normal',
		'high'
	);

	remove_meta_box( 'slugdiv', 'exortpress-spg', 'normal' );

}
add_action( 'add_meta_boxes', 'exortpress_spg_meta_box' );

/**
 * Prints the box content.
 *
 * @param WP_Post $post The object for the current post/page.
 */
function exortpress_spg_meta_box_callback( $post ) {
	wp_enqueue_script('jquery');
	// This will enqueue the Media Uploader script
	wp_enqueue_media();
	// Add a nonce field so we can check for it later.
	wp_nonce_field( 'exortpress_spg_meta_box', 'exortpress_spg_meta_box_nonce' );
	?>
	<style>
		.exortpress-metabox-container {
			overflow:hidden;
			padding-top:5px;
		}
		.exortpress_remove_when_clicked img {
			height:100px;
			margin-right:10px;
			margin-top:5px;
		}
		.exortpress_remove_when_clicked {
			float:left;
		}
		.exortpress_remove_when_clicked__remove_button {
			font-weight: bold;
		    text-decoration: underline;
		    cursor: pointer;
		}
		.exortpress_remove_when_clicked__remove_button:hover {
			color:red;
		}
	</style>
	<div class="exortpress-metabox-container">
		<div id="image_url" style="overflow:hidden;">
		<?php
			global $post;
			$post_id = $post->ID;
			$attachment_ids_string = get_post_meta( $post_id, 'attachment_ids', true );
			if(!empty($attachment_ids_string)) {
				$attachment_ids = explode(',', $attachment_ids_string);

				foreach($attachment_ids as $id) {
					?>
					<div class='exortpress_remove_when_clicked'>
						<img src="<?php echo wp_get_attachment_image_src($id, 'full')[0]; ?>" />
						<input type='hidden' class="attachment_id" name='attachment_id[]' value='<?php echo $id; ?>' />
						<div class="exortpress_remove_when_clicked__remove_button_wrapper">
							<span class="exortpress_remove_when_clicked__remove_button">Remove</span>
						</div>
					</div>
					<?php
				}
			}

		?>
		</div>
		<p style="color:#888;font-style:italic;">You can drag images to sort them.</p>
	    <input type="button" name="upload-btn" id="upload-btn" class="button-secondary" value="Upload Images or Select from Media Library">
	</div>
	<script type="text/javascript">
		jQuery(document).ready(function($){
			jQuery( "#image_url" ).sortable({ revert: true });
			jQuery(document).on('click','.exortpress_remove_when_clicked__remove_button',function(){
				jQuery(this).closest('.exortpress_remove_when_clicked').remove();
			});
		    $('#upload-btn').click(function(e) {
		        e.preventDefault();
		        var image = wp.media({
		            title: 'Upload Image',
		            multiple: true
		        });
		        image.on('open',function() {
					var selection = image.state().get('selection');
					jQuery('.attachment_id').each(function(){
						var id = jQuery(this).val();
						attachment = wp.media.attachment(id);
						attachment.fetch();
						selection.add( attachment ? [ attachment ] : [] );
					});
				});
		        image.on('select', function(e){
		            // This will return the selected image from the Media Uploader, the result is an object
		            var uploaded_images = image.state().get('selection');
		            var ids_array = new Array();
		            // We convert uploaded_image to a JSON object to make accessing it easier
		            // Output to the console uploaded_image
		            jQuery('#image_url').empty();
		            uploaded_images.map( function( attachment ) {
			            attachment = attachment.toJSON();
			            var to_be_appended = "<div class='exortpress_remove_when_clicked' style='float:left;'>";
			            to_be_appended = to_be_appended + "<img style='height:100px;margin-right:10px;' src=" + attachment.url + " />";
			            to_be_appended = to_be_appended + "<input type='hidden' class='attachment_id' name='attachment_id[]' value='" + attachment.id + "' />";
			            to_be_appended = to_be_appended + "<div class='exortpress_remove_when_clicked__remove_button_wrapper'>";
			            to_be_appended = to_be_appended + "<span class='exortpress_remove_when_clicked__remove_button'>Remove</span>";
			            to_be_appended = to_be_appended + "</div>";
			            to_be_appended = to_be_appended + "</div>";
			            jQuery('#image_url').append(to_be_appended);
		            });
		        });
		        image.open();
		    });
		});
	</script>


	<?php
}

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
function exortpress_spg_save_meta_box_data( $post_id ) {

	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['exortpress_spg_meta_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['exortpress_spg_meta_box_nonce'], 'exortpress_spg_meta_box' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */

	// Make sure that it is set.
	if ( ! isset( $_POST['attachment_id'] ) ) {
		return;
	}

	$ids = implode(',', $_POST['attachment_id']);

	// Update the meta field in the database.
	update_post_meta( $post_id, 'attachment_ids', $ids );
}
add_action( 'save_post', 'exortpress_spg_save_meta_box_data' );
